@@ -246,6 +246,7 @@ struct _VteTerminalPrivate {
 	GArray *word_chars;
 	gboolean has_selection;
 	gboolean selecting;
+	gboolean selecting_after_threshold;
 	gboolean selecting_restart;
 	gboolean selecting_had_delta;
 	gboolean selection_block_mode;
@@ -305,6 +306,7 @@ struct _VteTerminalPrivate {
 	long mouse_last_x, mouse_last_y;
 	gboolean mouse_autohide;
 	guint mouse_autoscroll_tag;
+	gboolean mouse_urxvt_extension;
 
 	/* State variables for handling match checks. */
 	char *match_contents;
@@ -397,6 +399,11 @@ struct _VteTerminalPrivate {
 #endif
 };
 
+#if GTK_CHECK_VERSION (2, 99, 0)
+struct _VteTerminalClassPrivate {
+        GtkStyleProvider *style_provider;
+};
+#endif
 
 VteRowData *_vte_terminal_ensure_row(VteTerminal *terminal);
 void _vte_terminal_set_pointer_visible(VteTerminal *terminal, gboolean visible);
